==> opie-2.2.tar.gz: opie-2.2/acconfig.h <==
/* acconfig.h: Extra commentary for Autoheader

 Portions of this software are Copyright 1996 by Craig Metz, All Rights
 Reserved. The Inner Net Copyright Notice and License Agreement applies to
 these portions of the software.

	History:

	Modified by cmetz for OPIE 2.2. Added a LOT of definitions.
	Created at NRL for OPIE 2.1.
*/

/* Define if the closedir function returns void instead of int.  */ 
#undef CLOSEDIR_VOID

/* Defined if the file /etc/default/login exists 
   (and, presumably, should be looked at by login) */
#undef HAVE_ETC_DEFAULT_LOGIN

/* Defined if the file /etc/fbtab exists
   (and, presumably, should be looked at by login) */
#undef HAVE_ETC_FBTAB

/* Defined if the file /etc/logindevperm exists
   (and, presumably, should be looked at by login) */
#undef HAVE_ETC_LOGINDEVPERM

/* Defined if the file /etc/securetty exists
   (and, presumably, should be looked at by login) */
#undef HAVE_ETC_SECURETTY

/* Defined if the file /etc/shadow exists
   (and, presumably, should be looked at for shadow passwords) */
#undef HAVE_ETC_SHADOW

/* The path to the access file, if we're going to use it */
#undef PATH_ACCESS_FILE

/* The path to the mail spool, if we know it */
#undef PATH_MAIL

/* The path to the utmp file, if we know it */
#undef PATH_UTMP_AC

/* The path to the utmpx file, if we know it */
#undef PATH_UTMPX_AC

/* The path to the wtmp file, if we know it */
#undef PATH_WTMP_AC

/* The path to the wtmpx file, if we know it */
#undef PATH_WTMPX_AC

/* Defined if the system's profile (/etc/profile) displays
   the motd file */
#undef HAVE_MOTD_IN_PROFILE

/* Defined if the system's profile (/etc/profile) informs the
   user of new mail */
#undef HAVE_MAILCHECK_IN_PROFILE

/* Define if the system has the getenv function */
#undef HAVE_GETENV

/* Define if the system has the setenv function */
#undef HAVE_SETENV

/* Define if the system has the sigmask macro */
#undef HAVE_SIGMASK_MACRO

/* Define if the system has the unsetenv function */
#undef HAVE_UNSETENV

/* Define if the compiler can handle ANSI-style argument lists */
#undef HAVE_ANSIDECL

/* Define if the compiler can handle ANSI-style prototypes */
#undef HAVE_ANSIPROTO

/* Define if the compiler can handle ANSI-style variable argument lists */
#undef HAVE_ANSISTDARG

/* Define if the compiler can handle void argument lists to functions */
#undef HAVE_VOIDARG

/* Define if the compiler can handle void return "values" from functions */
#undef HAVE_VOIDRET

/* Define if the compiler can handle void pointers to our liking */
#undef HAVE_VOIDPTR

/* Define if the /bin/ls command seems to support the -g flag */
#undef HAVE_LS_G_FLAG

/* Define if there is a ut_pid field in struct utmp (is this ever NOT true?) */
#undef HAVE_UT_PID

/* Define if there is a ut_type field in struct utmp */
#undef HAVE_UT_TYPE

==> opie-2.22.tar.gz: opie-2.22/acconfig.h <==
/* acconfig.h: Extra commentary for Autoheader
*//* 
 Portions of this software are Copyright 1996 by Craig Metz, All Rights
 Reserved. The Inner Net Copyright Notice and License Agreement applies to
 these portions of the software.
*//* 
	History:
*//* 
	Modified by cmetz for OPIE 2.22. Added HAVE_ONE_ARG_GETTIMEOFDAY.
	Modified by cmetz for OPIE 2.2. Added a LOT of definitions.
	Created at NRL for OPIE 2.1.
*/
#undef AUTOHEADER_DRAIN_BAMAGE

/* Define if the closedir function returns void instead of int.  */ 
#undef CLOSEDIR_VOID

/* Defined if the file /etc/default/login exists 
   (and, presumably, should be looked at by login) */
#undef HAVE_ETC_DEFAULT_LOGIN

/* Defined if the file /etc/fbtab exists
   (and, presumably, should be looked at by login) */
#undef HAVE_ETC_FBTAB

/* Defined if the file /etc/logindevperm exists
   (and, presumably, should be looked at by login) */
#undef HAVE_ETC_LOGINDEVPERM

/* Defined if the file /etc/securetty exists
   (and, presumably, should be looked at by login) */
#undef HAVE_ETC_SECURETTY

/* Defined if the file /etc/shadow exists
   (and, presumably, should be looked at for shadow passwords) */
#undef HAVE_ETC_SHADOW

/* The path to the access file, if we're going to use it */
#undef PATH_ACCESS_FILE

/* The path to the mail spool, if we know it */
#undef PATH_MAIL

/* The path to the utmp file, if we know it */
#undef PATH_UTMP_AC

/* The path to the utmpx file, if we know it */
#undef PATH_UTMPX_AC

/* The path to the wtmp file, if we know it */
#undef PATH_WTMP_AC

/* The path to the wtmpx file, if we know it */
#undef PATH_WTMPX_AC

/* Defined if the system's profile (/etc/profile) displays
   the motd file */
#undef HAVE_MOTD_IN_PROFILE

/* Defined if the system's profile (/etc/profile) informs the
   user of new mail */
#undef HAVE_MAILCHECK_IN_PROFILE

/* Define if the system has the getenv function */
#undef HAVE_GETENV

/* Define if the system has the setenv function */
#undef HAVE_SETENV

/* Define if the system has the sigmask macro */
#undef HAVE_SIGMASK_MACRO

/* Define if the system has the unsetenv function */
#undef HAVE_UNSETENV

/* Define if the compiler can handle ANSI-style argument lists */
#undef HAVE_ANSIDECL

/* Define if the compiler can handle ANSI-style prototypes */
#undef HAVE_ANSIPROTO

/* Define if the compiler can handle ANSI-style variable argument lists */
#undef HAVE_ANSISTDARG

/* Define if the compiler can handle void argument lists to functions */
#undef HAVE_VOIDARG

/* Define if the compiler can handle void return "values" from functions */
#undef HAVE_VOIDRET

/* Define if the compiler can handle void pointers to our liking */
#undef HAVE_VOIDPTR

/* Define if the /bin/ls command seems to support the -g flag */
#undef HAVE_LS_G_FLAG

/* Define if there is a ut_pid field in struct utmp (is this ever NOT true?) */
#undef HAVE_UT_PID

/* Define if there is a ut_type field in struct utmp */
#undef HAVE_UT_TYPE

/* Define if you have a nonstandard gettimeofday() that takes one argument
   instead of two. */
#undef HAVE_ONE_ARG_GETTIMEOFDAY
